@@ -26,10 +26,10 @@ where
         let mut values = vec![];
         let mut state = self.input.state();
         let start_pos = self.input.cur_span()?.lo;
-
         let mut hi = self.input.last_pos()?;
+
         loop {
-            if is_one_of!(self, EOF, ";", "}", "!", ")") {
+            if is_one_of!(self, EOF, ";", "}", "!", ")", "]") {
                 self.input.reset(&state);
                 break;
             }
@@ -47,12 +47,12 @@ where
 
             if !eat!(self, " ") {
                 if self.ctx.recover_from_property_value
-                    && !is_one_of!(self, EOF, ";", "}", "!", ")")
+                    && !is_one_of!(self, EOF, ";", "}", "!", ")", "]")
                 {
                     self.input.reset(&start);
 
                     let mut tokens = vec![];
-                    while !is_one_of!(self, EOF, ";", "}", "!", ")") {
+                    while !is_one_of!(self, EOF, ";", "}", "!", ")", "]") {
                         tokens.extend(self.input.bump()?);
                     }
 
@@ -213,7 +213,7 @@ where
 
             Token::Ident { .. } => return self.parse_value_ident_or_fn(),
 
-            tok!("[") => return self.parse_array_value().map(From::from),
+            tok!("[") => return self.parse_square_brackets_value().map(From::from),
 
             tok!("(") => return self.parse_paren_value().map(From::from),
 
@@ -500,22 +500,28 @@ where
         Ok(args)
     }
 
-    fn parse_array_value(&mut self) -> PResult<ArrayValue> {
+    fn parse_square_brackets_value(&mut self) -> PResult<SquareBracketBlock> {
         let span = self.input.cur_span()?;
 
         expect!(self, "[");
 
+        self.input.skip_ws()?;
+
         let ctx = Ctx {
             is_in_delimited_value: true,
+            allow_separating_value_with_space: true,
             ..self.ctx
         };
-        let values = self.with_ctx(ctx).parse_comma_separated_value()?;
+
+        let children = Some(self.with_ctx(ctx).parse_property_values()?.0);
+
+        self.input.skip_ws()?;
 
         expect!(self, "]");
 
-        Ok(ArrayValue {
+        Ok(SquareBracketBlock {
             span: span!(self, span.lo),
-            values,
+            children,
         })
     }
 
